==> xsns_1.0.2.zip: xsns_1.0.2/xoops_trust_path/modules/xsns/act/topic/del_execAction.php <==
<?php
class del_execAction extends topicAction
{

function dispatch(&$context)
{
	global $xoopsUser;
	if($this->isGuest() || !$this->validateToken('TOPIC_DELETE')){
		redirect_header(_CM_URL_COMMU, 2, _NOPERM);
	}
	$own_uid = $xoopsUser->getVar('uid');
	
	$tid = $this->getIntRequest('tid', APP_REQUEST_GET);
	$num = $this->getIntRequest('n', APP_REQUEST_GET);
	
	if(!isset($tid) || !isset($num)){
		redirect_header(_CM_URL_COMMU, 2, _NOPERM);
	}
	
	$commu_handler =& CM_CommunityHandler::getInstance();
	$topic_handler =& CM_TopicHandler::getInstance();
	$comment_handler =& CM_TopicCommentHandler::getInstance();
	$user_handler =& CM_UserHandler::getInstance();
	
	// ȥԥåμ
	$topic =& $topic_handler->get($tid);
	if(!is_object($topic)){
		redirect_header(_CM_URL_COMMU, 2, _NOPERM);
	}
	$topic_uid = $topic->getVar('uid');
	
	// ߥ˥ƥμ
	$cid = $topic->getVar('c_commu_id');
	$community =& $commu_handler->get($cid);
	if(!is_object($community)){
		redirect_header(_CM_URL_COMMU, 2, _NOPERM);
	}
	$commu_auth = $community->getAuthority();
	if($commu_auth < _CM_AUTH_MEMBER){
		redirect_header(_CM_URL_COMMU, 2, _NOPERM);
	}
	
	// Ȥμ
	$comment =& $comment_handler->getByNumber($tid, $num);
	$comment_uid = $comment->getVar('uid');
	if(!is_object($comment) || $comment_uid < 1
	   || ($commu_auth < _CM_AUTH_SUB_ADMIN && $own_uid != $comment_uid && $own_uid != $topic_uid)){
		redirect_header(_CM_URL_COMMU, 2, _NOPERM);
	}
	
	if($num > 0){
		$tcid = $comment->getVar('c_commu_topic_comment_id');
		
		// Ȥκ  ƼԡʸǡΤߺ
		$comment->setVar('uid', 0);
		$comment->setVar('body', '');
		
		if($comment_handler->insert($comment)){
			// Ȥźդ줿ե
			$criteria = new CriteriaCompo(new Criteria('target', 2));
			$criteria->add(new Criteria('target_id', $tcid));
			$image_handler =& CM_ImageHandler::getInstance();
			$image_handler->deleteObjects($criteria);
			$file_handler =& CM_FileHandler::getInstance();
			$file_handler->deleteObjects($criteria);
			
			redirect_header(_CM_URL_TOPIC.'&tid='.$tid, 2, _CM_TOPIC_DEL_RES_OK);
		}
		redirect_header(_CM_URL_TOPIC.'&tid='.$tid, 2, _CM_TOPIC_DEL_RES_NG);
	}
	else{
		// ȥԥåκ  ȥԥåӥȤ˺
		if($topic->deleteCommentsAll() && $topic_handler->delete($topic)){
			redirect_header(_CM_URL_COMMU.'?cid='.$cid, 2, _CM_TOPIC_DEL_OK);
		}
		redirect_header(_CM_URL_TOPIC.'&tid='.$tid, 2, _CM_TOPIC_DEL_NG);
	}
}
}
?>

==> xsns_1.0.4.zip: xsns_1.0.4/xoops_trust_path/modules/xsns/act/topic/del_execAction.php <==
<?php
class del_execAction extends topicAction
{

function dispatch(&$context)
{
	global $xoopsUser;
	if($this->isGuest() || !$this->validateToken('TOPIC_DELETE')){
		redirect_header(_CM_URL_COMMU, 2, _NOPERM);
	}
	$own_uid = $xoopsUser->getVar('uid');
	
	$tid = $this->getIntRequest('tid');
	$num = $this->getIntRequest('n');
	
	if(!isset($tid) || !isset($num)){
		redirect_header(_CM_URL_COMMU, 2, _NOPERM);
	}
	
	$commu_handler =& CM_CommunityHandler::getInstance();
	$topic_handler =& CM_TopicHandler::getInstance();
	$comment_handler =& CM_TopicCommentHandler::getInstance();
	$user_handler =& CM_UserHandler::getInstance();
	
	// ȥԥåμ
	$topic =& $topic_handler->get($tid);
	if(!is_object($topic)){
		redirect_header(_CM_URL_COMMU, 2, _NOPERM);
	}
	$topic_uid = $topic->getVar('uid');
	
	// ߥ˥ƥμ
	$cid = $topic->getVar('c_commu_id');
	$community =& $commu_handler->get($cid);
	if(!is_object($community)){
		redirect_header(_CM_URL_COMMU, 2, _NOPERM);
	}
	$commu_auth = $community->getAuthority();
	if($commu_auth < _CM_AUTH_MEMBER){
		redirect_header(_CM_URL_COMMU, 2, _NOPERM);
	}
	
	// Ȥμ
	$comment =& $comment_handler->getByNumber($tid, $num);
	$comment_uid = $comment->getVar('uid');
	if(!is_object($comment) || $comment_uid < 1
	   || ($commu_auth < _CM_AUTH_SUB_ADMIN && $own_uid != $comment_uid && $own_uid != $topic_uid)){
		redirect_header(_CM_URL_COMMU, 2, _NOPERM);
	}
	
	if($num > 0){
		$tcid = $comment->getVar('c_commu_topic_comment_id');
		
		// Ȥκ  ƼԡʸǡΤߺ
		$comment->setVar('uid', 0);
		$comment->setVar('body', '');
		
		if($comment_handler->insert($comment)){
			// Ȥźդ줿ե
			$criteria = new CriteriaCompo(new Criteria('target', 2));
			$criteria->add(new Criteria('target_id', $tcid));
			$image_handler =& CM_ImageHandler::getInstance();
			$image_handler->deleteObjects($criteria);
			$file_handler =& CM_FileHandler::getInstance();
			$file_handler->deleteObjects($criteria);
			
			redirect_header(_CM_URL_TOPIC.'&tid='.$tid, 2, _CM_TOPIC_DEL_RES_OK);
		}
		redirect_header(_CM_URL_TOPIC.'&tid='.$tid, 2, _CM_TOPIC_DEL_RES_NG);
	}
	else{
		// ȥԥåκ  ȥԥåӥȤ˺
		if($topic->deleteCommentsAll() && $topic_handler->delete($topic)){
			redirect_header(_CM_URL_COMMU.'?cid='.$cid, 2, _CM_TOPIC_DEL_OK);
		}
		redirect_header(_CM_URL_TOPIC.'&tid='.$tid, 2, _CM_TOPIC_DEL_NG);
	}
}
}
?>
